@@ -1,6 +1,6 @@
 # This is the PyQt5 build script.
 #
-# Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
+# Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 # 
 # This file is part of PyQt5.
 # 
@@ -27,27 +27,33 @@ from sipbuild import (Buildable, BuildableModule, Installable, Option,
         UserException)
 
 
+# The minimum sip module ABI version needed.
+ABI_VERSION = '12.11'
+
+
 class PyQt(PyQtProject):
     """ The PyQt5 project. """
 
     def __init__(self):
         """ Initialise the project. """
 
-        super().__init__(dunder_init=True, tag_prefix='Qt',
-                console_scripts=[
+        # We specify the name of the sip module because PyQt-builder doesn't
+        # provide it if we are creating an sdist.
+        super().__init__(abi_version=ABI_VERSION, sip_module='PyQt5.sip',
+                dunder_init=True, tag_prefix='Qt', console_scripts=[
                     'pylupdate5 = PyQt5.pylupdate_main:main',
                     'pyrcc5 = PyQt5.pyrcc_main:main',
                     'pyuic5 = PyQt5.uic.pyuic:main'])
 
         # Each set of bindings must appear after any set they depend on.
-        self.bindings_factories = [Qt, QtCore, QtNetwork, QtGui, QtWidgets,
-            QtQml, QAxContainer, QtAndroidExtras, QtBluetooth, QtDBus,
-            QtDesigner, Enginio, QtHelp, QtMacExtras, QtMultimedia,
-            QtMultimediaWidgets, QtNetworkAuth, QtNfc, QtOpenGL, QtPositioning,
-            QtLocation, QtPrintSupport, QtQuick, QtQuickWidgets,
-            QtRemoteObjects, QtSensors, QtSerialPort, QtSql, QtSvg, QtTest,
-            QtWebChannel, QtWebKit, QtWebKitWidgets, QtWebSockets, QtWinExtras,
-            QtX11Extras, QtXml, QtXmlPatterns, _QOpenGLFunctions_2_0,
+        self.bindings_factories = [QtCore, QtNetwork, QtGui, QtWidgets, QtQml,
+            QAxContainer, QtAndroidExtras, QtBluetooth, QtDBus, QtDesigner,
+            Enginio, QtHelp, QtMacExtras, QtMultimedia, QtMultimediaWidgets,
+            QtNfc, QtOpenGL, QtPositioning, QtLocation, QtPrintSupport,
+            QtQuick, QtQuick3D, QtQuickWidgets, QtRemoteObjects, QtSensors,
+            QtSerialPort, QtSql, QtSvg, QtTest, QtTextToSpeech, QtWebChannel,
+            QtWebKit, QtWebKitWidgets, QtWebSockets, QtWinExtras, QtX11Extras,
+            QtXml, QtXmlPatterns, Qt, _QOpenGLFunctions_2_0,
             _QOpenGLFunctions_2_1, _QOpenGLFunctions_4_1_Core,
             _QOpenGLFunctions_ES2, pylupdate, pyrcc]
 
@@ -82,7 +88,7 @@ def find_qt():
     if not os.path.isfile(dll_dir + qtcore_dll):
         path = os.environ['PATH']
 
-        dll_dir = os.path.dirname(__file__) + '\\\\Qt\\\\bin'
+        dll_dir = os.path.dirname(__file__) + '\\\\Qt5\\\\bin'
         if os.path.isfile(dll_dir + qtcore_dll):
             path = dll_dir + ';' + path
             os.environ['PATH'] = path
@@ -154,6 +160,12 @@ del find_qt
         if tool not in Option.BUILD_TOOLS:
             return
 
+        # Check we support the version of Qt.
+        if self.builder.qt_version >> 16 != 5:
+            raise UserException(
+                    "Qt v5 is required, not v{0}".format(
+                            self.builder.qt_version_str))
+
         # Automatically confirm the license if there might not be a command
         # line option to do so.
         if tool == 'pep517':
@@ -172,7 +184,7 @@ del find_qt
         self.bindings['QtCore'].tags.append(plattag)
 
         # Make sure the bindings are buildable.
-        self.update_buildable_bindings()
+        super().update(tool)
 
         # PyQtWebEngine needs to know if QtWebChannel is available.
         if 'QtWebChannel' not in self.bindings:
@@ -182,29 +194,38 @@ del find_qt
 
         # Add the composite module.
         if 'Qt' in self.bindings:
-            self._add_composite_module(tool)
+            self._add_composite_module()
 
         # Always install the uic module.
         installable = Installable('uic', target_subdir='PyQt5')
         installable.files.append(os.path.join(self.root_dir, 'pyuic', 'uic'))
         self.installables.append(installable)
 
+        # If any set of bindings is being built as a debug version then assume
+        # the plugins and DBus support should as well.
+        for bindings in self.bindings.values():
+            if bindings.debug:
+                others_debug = True
+                break
+        else:
+            others_debug = self.py_debug
+
         # Add the plugins.  For the moment we don't include them in wheels.
         # This may change when we improve the bundling of Qt.
         if tool in ('build', 'install'):
             if self.designer_plugin and 'QtDesigner' in self.bindings:
                 self._add_plugin('designer', "Qt Designer", 'pyqt5',
-                        'designer')
+                        'designer', others_debug)
 
             if self.qml_plugin and 'QtQml' in self.bindings:
                 self._add_plugin('qmlscene', "qmlscene", 'pyqt5qmlplugin',
-                        'PyQt5')
+                        'PyQt5', others_debug)
 
         # Add the dbus-python support.
         if self.dbus_python:
-            self._add_dbus()
+            self._add_dbus(others_debug)
 
-    def _add_composite_module(self, tool):
+    def _add_composite_module(self):
         """ Add the bindings for the composite module. """
 
         sip_file = os.path.join(self.build_dir, 'Qt.sip')
@@ -224,7 +245,7 @@ del find_qt
 
         self.bindings['Qt'].sip_file = sip_file
 
-    def _add_dbus(self):
+    def _add_dbus(self, debug):
         """ Add the dbus-python support. """
 
         self.progress(
@@ -287,11 +308,11 @@ del find_qt
         buildable.include_dirs.extend(dbus_inc_dirs)
         buildable.library_dirs.extend(dbus_lib_dirs)
         buildable.libraries.extend(dbus_libs)
-        buildable.debug = self.py_debug
+        buildable.debug = debug
 
         self.buildables.append(buildable)
 
-    def _add_plugin(self, name, user_name, target_name, target_subdir):
+    def _add_plugin(self, name, user_name, target_name, target_subdir, debug):
         """ Add a plugin to the project buildables. """
 
         builder = self.builder
@@ -330,8 +351,7 @@ del find_qt
         with open(os.path.join(root_plugin_dir, name + '.pro-in')) as f:
             prj = f.read()
 
-        prj = prj.replace('@QTCONFIG@',
-                'debug' if self.py_debug else 'release')
+        prj = prj.replace('@QTCONFIG@', 'debug' if debug else 'release')
         prj = prj.replace('@PYINCDIR@',
                 builder.qmake_quote(self.py_include_dir))
         prj = prj.replace('@SIPINCDIR@', builder.qmake_quote(self.build_dir))
@@ -747,19 +767,6 @@ class QtNetwork(PyQtBindings):
         super().__init__(project, 'QtNetwork', qmake_QT=['network', '-gui'])
 
 
-class QtNetworkAuth(PyQtBindings):
-    """ The QtNetworkAuth bindings. """
-
-    def __init__(self, project):
-        """ Initialise the bindings. """
-
-        super().__init__(project, 'QtNetworkAuth',
-                qmake_CONFIG=['c++11'],
-                qmake_QT=['network', 'networkauth', '-gui'],
-                test_headers=['qtnetworkauthversion.h'],
-                test_statement='const char *v = QTNETWORKAUTH_VERSION_STR')
-
-
 class QtNfc(PyQtBindings):
     """ The QtNfc bindings. """
 
@@ -822,6 +829,17 @@ class QtQuick(PyQtBindings):
                 test_statement='new QQuickWindow()')
 
 
+class QtQuick3D(PyQtBindings):
+    """ The QtQuick3D bindings. """
+
+    def __init__(self, project):
+        """ Initialise the bindings. """
+
+        super().__init__(project, 'QtQuick3D', qmake_QT=['quick3d'],
+                test_headers=['qquick3d.h'],
+                test_statement='QQuick3D::idealSurfaceFormat()')
+
+
 class QtQuickWidgets(PyQtBindings):
     """ The QtQuickWidgets bindings. """
 
@@ -899,6 +917,18 @@ class QtTest(PyQtBindings):
                 test_headers=['QtTest'], test_statement='QTest::qSleep(0)')
 
 
+class QtTextToSpeech(PyQtBindings):
+    """ The QtTextToSpeech bindings. """
+
+    def __init__(self, project):
+        """ Initialise the bindings. """
+
+        super().__init__(project, 'QtTextToSpeech',
+                qmake_QT=['texttospeech', '-gui'],
+                test_headers=['QTextToSpeech'],
+                test_statement='new QTextToSpeech()')
+
+
 class QtWebChannel(PyQtBindings):
     """ The QtWebChannel bindings. """
 
